@@ -13,6 +13,7 @@ class QolsysTableShades(QolsysTable):
         self._uri = "content://com.qolsys.qolsysprovider.ShadesContentProvider/shades"
         self._table = "shades"
         self._abort_on_error = False
+        self._implemented = False
 
         self._columns = [
             "_id",
@@ -20,8 +21,3 @@ class QolsysTableShades(QolsysTable):
 
         self._create_table()
 
-    def insert(self, data: dict) -> None:
-        if data is not None:
-            LOGGER.error("Please Report")
-            LOGGER.error("Loading Table Format: %s", self.uri)
-            LOGGER.error(data)
