@@ -13,15 +13,10 @@ class QolsysTableZwaveOther(QolsysTable):
         self._uri = "content://com.qolsys.qolsysprovider.ZwaveOtherDeviceContentProvider/zwave_other"
         self._table = "zwave_other"
         self._abort_on_error = False
+        self._implemented = False
 
         self._columns = [
             "_id",
         ]
 
         self._create_table()
-
-    def insert(self, data: dict) -> None:
-        if data is not None:
-            LOGGER.error("Please Report")
-            LOGGER.error("Loading Table Format: %s", self.uri)
-            LOGGER.error(data)
