@@ -39,8 +39,8 @@ class QolsysPartition(QolsysObservable):
 
         # Other
         self._command_exit_sounds = True
-        self._command_silent_disarming = False
         self._command_arm_stay_instant = True
+        self._command_arm_stay_silent_disarming = False
 
     @property
     def id(self) -> int:
@@ -83,12 +83,8 @@ class QolsysPartition(QolsysObservable):
         return self._command_arm_stay_instant
 
     @property
-    def command_silent_disarming(self) -> bool:
-        return self._command_silent_disarming
-
-    @command_silent_disarming.setter
-    def command_silent_disarming(self, value: bool) -> None:
-        self._command_silent_disarming = value
+    def command_arm_stay_silent_disarming(self) -> bool:
+        return self._command_arm_stay_silent_disarming
 
     @system_status.setter
     def system_status(self, new_value: PartitionSystemStatus) -> None:
@@ -188,6 +184,12 @@ class QolsysPartition(QolsysObservable):
         LOGGER.debug("Partition%s (%s) - arm_stay_instant: %s", self._id, self._name, value)
         self.notify()
 
+    @command_arm_stay_silent_disarming.setter
+    def command_arm_stay_silent_disarming(self, value: bool) -> None:
+        self._command_arm_stay_silent_disarming = value
+        LOGGER.debug("Partition%s (%s) - arm_stay_silent_disarming: %s", self._id, self._name, value)
+        self.notify()
+
     def update_partition(self, data: dict) -> None:
         # Check if we are updating same partition_id
         partition_id_update = data.get("partition_id", "")
